<?php

namespace Drupal\layout_builder_ipe\Controller;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\ReplaceCommand;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines a base controller to provide the Layout Builder admin UI.
 *
 * @internal
 *   Controller classes are internal.
 */
abstract class BaseController extends ControllerBase {

  /**
   * The layout builder ipe service.
   *
   * @var \Drupal\layout_builder_ipe\LayoutBuilderIpeService
   */
  protected $layoutBuilderIpe;

  /**
   * Layout tempstore repository.
   *
   * @var \Drupal\layout_builder\LayoutTempstoreRepositoryInterface
   */
  protected $layoutTempstoreRepository;

  /**
   * The current request.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->layoutBuilderIpe = $container->get('layout_builder_ipe');
    $instance->layoutTempstoreRepository = $container->get('layout_builder.tempstore_repository');
    $instance->tempstore = $container->get('tempstore.shared');
    $instance->requestStack = $container->get('request_stack');
    return $instance;
  }

  protected function ajaxResponse($content, $editing = TRUE) {
    $response = new AjaxResponse();
    if (!empty($content)) {
      $response->addCommand(new ReplaceCommand('#layout-builder-ipe-wrapper', [
        '#type' => 'container',
        '#prefix' => '<div id="layout-builder-ipe-wrapper" class="' . ($editing ? 'edit-layout' : '') . '">',
        '#suffix' => '</div>',
        $content,
      ]));
    }
    return $response;
  }

}
