<?php

namespace Drupal\layout_builder_ipe\Controller;

use Drupal\layout_builder\SectionStorageInterface;

/**
 * Defines a base controller for content entities.
 *
 * @internal
 *   Controller classes are internal.
 */
abstract class EntityBaseController extends BaseController {

  /**
   * Build an ajax response.
   *
   * @param \Drupal\layout_builder\SectionStorageInterface $section_storage
   *   The section storage.
   *
   * @return \Drupal\Core\Ajax\AjaxResponse
   *   The response containing the layout builder form.
   */
  protected function buildAjaxResponse(SectionStorageInterface $section_storage) {
    $layout_builder_layout = NULL;
    $layout_builder_form = NULL;
    $layout_builder_message = NULL;

    $entity = $this->layoutBuilderIpe->getEntityFromSectionStorage($section_storage);

    // Get the layout builder form.
    $form_class = $entity->getEntityType()->getFormClass('layout_builder');
    if ($entity && $form_class) {
      $additional_form_state = [
        'build_info' => [
          'args' => [
            'section_storage' => $section_storage,
          ],
        ],
      ];
      $layout_builder_form = $this->entityFormBuilder()->getForm($entity, 'layout_builder', $additional_form_state);
      $layout_builder_layout = $layout_builder_form['layout_builder__layout'];
      // $layout_builder_message = $layout_builder_form['layout_builder_message'];
      unset($layout_builder_form['layout_builder__layout']);
      unset($layout_builder_form['layout_builder_message']);
    }

    return $this->ajaxResponse([$layout_builder_layout, $layout_builder_form, $layout_builder_message]);
  }

}
